@@ -1,32 +1,22 @@
+#define PY_SSIZE_T_CLEAN
 #include "Python.h"
 #include "pyobjc-api.h"
 
 #import <dispatch/dispatch.h>
 
 static PyObjC_function_map function_map[] = {
-    { "dispatch_get_main_queue", (PyObjC_Function_Pointer)&dispatch_get_main_queue },
-    { 0, 0 }
-};
+    {"dispatch_get_main_queue", (PyObjC_Function_Pointer)&dispatch_get_main_queue},
+    {0, 0}};
 
 static PyMethodDef mod_methods[] = {
-        { 0, 0, 0, 0 } /* sentinel */
+    {0, 0, 0, 0} /* sentinel */
 };
 
-
 /* Python glue */
 #if PY_MAJOR_VERSION == 3
 
 static struct PyModuleDef mod_module = {
-    PyModuleDef_HEAD_INIT,
-    "_inlines",
-    NULL,
-    0,
-    mod_methods,
-    NULL,
-    NULL,
-    NULL,
-    NULL
-};
+    PyModuleDef_HEAD_INIT, "_inlines", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
 
 #define INITERROR() return NULL
 #define INITDONE() return m
@@ -51,15 +41,14 @@ init_inlines(void)
 #if PY_MAJOR_VERSION == 3
     m = PyModule_Create(&mod_module);
 #else
-    m = Py_InitModule4("_inlines", mod_methods,
-            NULL, NULL, PYTHON_API_VERSION);
+    m = Py_InitModule4("_inlines", mod_methods, NULL, NULL, PYTHON_API_VERSION);
 #endif
     if (!m) {
-            INITERROR();
+        INITERROR();
     }
 
-    if (PyModule_AddObject(m, "_inline_list_",
-        PyObjC_CreateInlineTab(function_map)) < 0) {
+    if (PyModule_AddObject(m, "_inline_list_", PyObjC_CreateInlineTab(function_map)) <
+        0) {
         INITERROR();
     }
 
